.. _all-salt.returners:

================
returner modules
================

.. currentmodule:: salt.returners

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    highstate_return
    local
    local_cache
    multi_returner
    pgjsonb
    postgres
    postgres_local_cache
    rawfile_json
    syslog_return
